from setuptools import setup

setup(
    name = 'LinguaFrancaBase',
    version = '1.0',
    description = 'Useful notations and helper functions used in Lingua Franca programs.',
    author= 'Soroush Bateni',
    author_email="soroosh129@gmail.com",
    url="https://github.com/icyphy/lingua-franca",
    packages = ['LinguaFrancaBase'],
    python_requires='>=3.4',
)